@@ -26,23 +26,29 @@ class ProposalApi(Base):
         api_url = self.__get_api_url('{0}{1}'.format('/by_number/', number))
         return self.api_get(api_url, params={})
 
-    def get_proposal_by_number_daq_info_api(self, number):
+    def get_proposal_by_number_daq_info_api(self, number,
+                                            page=1, page_size=100):
         api_url = self.__get_api_url('{0}{1}'.format('/by_number_daq_info/',
                                                      number))
-        return self.api_get(api_url, params={})
+        return self.api_get(api_url,
+                            params={'page': page, 'page_size': page_size})
 
     def get_runs_by_proposal_number_api(self,
-                                        proposal_number, run_number=None):
+                                        proposal_number, run_number=None,
+                                        page=1, page_size=100):
         api_specifics = '{0}{1}{2}'.format('by_number/',
                                            proposal_number, '/runs')
         if run_number:
             api_specifics = '{0}/{1}'.format(api_specifics, run_number)
         api_url = self.__get_api_url(api_specifics)
-        return self.api_get(api_url)
+        return self.api_get(api_url,
+                            params={'page': page, 'page_size': page_size})
 
-    def get_all_proposals_by_number_api(self, number):
+    def get_all_proposals_by_number_api(self, number, page=1, page_size=100):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'number': number})
+        return self.api_get(api_url, params={'number': number,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
