@@ -22,14 +22,19 @@ class SampleApi(Base):
         api_url = self.__get_api_url(sample_id)
         return self.api_get(api_url, params={})
 
-    def get_all_samples_by_proposal_id_api(self, proposal_id):
-        api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'proposal_id': proposal_id})
-
-    def get_all_samples_by_name_and_proposal_id_api(self, name, proposal_id):
+    def get_all_samples_by_proposal_id_api(self, proposal_id,
+                                           page=1, page_size=100):
         api_url = self.__get_api_url()
         return self.api_get(api_url,
-                            params={'name': name, 'proposal_id': proposal_id})
+                            params={'proposal_id': proposal_id,
+                                    'page': page, 'page_size': page_size})
+
+    def get_all_samples_by_name_and_proposal_id_api(self, name, proposal_id,
+                                                    page=1, page_size=100):
+        api_url = self.__get_api_url()
+        return self.api_get(api_url,
+                            params={'name': name, 'proposal_id': proposal_id,
+                                    'page': page, 'page_size': page_size})
 
     #
     # Private Methods
