@@ -87,13 +87,15 @@ class MetadataClient(
 
         return resp
 
-    def get_proposal_runs(self, proposal_number, run_number=None):
+    def get_proposal_runs(self, proposal_number,
+                          run_number=None, page=1, page_size=100):
         logging.debug('proposal_number: {0}'.format(proposal_number))
 
         # Get PROPOSAL #id from #number
         resp = Proposal.get_runs_by_proposal_number(self,
                                                     proposal_number,
-                                                    run_number)
+                                                    run_number,
+                                                    page, page_size)
 
         number_of_runs = len(resp['data']['runs']) if 'runs' in resp[
             'data'] else 0
@@ -115,7 +117,7 @@ class MetadataClient(
         resp = Experiment.get_all_by_proposal_id(self, proposal_id)
         return resp
 
-    def get_proposal_samples(self, proposal_number):
+    def get_proposal_samples(self, proposal_number, page=1, page_size=100):
         logging.debug('proposal_number: {0}'.format(proposal_number))
 
         # Get PROPOSAL #id from #number
@@ -127,7 +129,7 @@ class MetadataClient(
 
         proposal_id = resp['data']['id']
         logging.debug('proposal_id: {0}'.format(proposal_id))
-        resp = Sample.get_all_by_proposal_id(self, proposal_id)
+        resp = Sample.get_all_by_proposal_id(self, proposal_id, page, page_size)
         return resp
 
     def register_run(self, experiment_id, sample_id,
