@@ -104,8 +104,8 @@ class Proposal:
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_number(mdc_client, number):
-        response = mdc_client.get_all_proposals_by_number_api(number)
+    def get_all_by_number(mdc_client, number, page=1, page_size=100):
+        response = mdc_client.get_all_proposals_by_number_api(number, page, page_size)
 
         curr_method_name = inspect.currentframe().f_code.co_name
         Base.cal_debug(MODULE_NAME, curr_method_name, response)
@@ -120,18 +120,19 @@ class Proposal:
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_by_number_daq_info(mdc_client, number):
-        response = mdc_client.get_proposal_by_number_daq_info_api(number)
+    def get_by_number_daq_info(mdc_client, number, page=1, page_size=100):
+        response = mdc_client.get_proposal_by_number_daq_info_api(number, page, page_size)
 
         curr_method_name = inspect.currentframe().f_code.co_name
         Base.cal_debug(MODULE_NAME, curr_method_name, response)
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_runs_by_proposal_number(mdc_client,
-                                    proposal_number, run_number=None):
+    def get_runs_by_proposal_number(mdc_client, proposal_number,
+                                    run_number=None, page=1, page_size=100):
         response = mdc_client.get_runs_by_proposal_number_api(proposal_number,
-                                                              run_number)
+                                                              run_number,
+                                                              page, page_size)
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
