@@ -294,9 +294,9 @@ class ProposalApiTest(ApiBase, unittest.TestCase):
         field = 'description'
         self.assert_not_eq_str(expect[field], expect_upd[field], field)
 
-    def __get_all_entries_by_number_api(self, number, expect):
-        response = self.client_api.get_all_proposals_by_number_api(number)
-        receive = self.get_and_validate_all_entries_by_name(response)
+    def __get_all_entries_by_number_api(self, number, expect, page=1, page_size=100):
+        resp = self.client_api.get_all_proposals_by_number_api(number, page, page_size)
+        receive = self.get_and_validate_all_entries_by_name(resp)
         self.fields_validation(receive, expect)
 
     def __get_proposal_by_number_api(self, number, expect):
@@ -310,9 +310,9 @@ class ProposalApiTest(ApiBase, unittest.TestCase):
 
         self.fields_validation(receive, expect)
 
-    def __get_proposal_by_number_daq_info_api(self, number, expect):
-        response = self.client_api.get_proposal_by_number_daq_info_api(number)
-        receive = self.get_and_validate_entry_by_id(response)
+    def __get_proposal_by_number_daq_info_api(self, number, expect, page=1, page_size=100):
+        resp = self.client_api.get_proposal_by_number_daq_info_api(number, page, page_size)
+        receive = self.get_and_validate_entry_by_id(resp)
 
         # Fix this values because they depend on the moment the tests are run!
         expect['begin_at'] = receive['begin_at']
