@@ -148,7 +148,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
 
-    def test_get_proposal_runs(self):
+    def test_get_proposal_runs_all_runs(self):
         proposal_number = 0
         resp = self.mdc_client.get_proposal_runs(proposal_number)
 
@@ -190,6 +190,8 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assert_eq_val(resp['success'], True)
         self.assert_eq_val(resp['info'], 'Got proposal successfully')
 
+        self.assert_eq_val(len(resp['data']['runs']), 2)
+
         first_run = resp['data']['runs'][0]
         self.assert_eq_val(first_run['id'], -1)
         self.assert_eq_val(first_run['run_number'], 1)
@@ -203,6 +205,59 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assert_eq_val(first_repo['mount_point'], '/webstorage/XFEL')
         self.assert_eq_val(first_repo['data_groups'], 1)
 
+        second_run = resp['data']['runs'][1]
+        self.assert_eq_val(second_run['id'], -2)
+        self.assert_eq_val(second_run['run_number'], 2)
+        self.assert_eq_val(second_run['flg_status'], 1)
+        self.assert_eq_val(second_run['flg_run_quality'], -1)
+        self.assert_eq_val(second_run['num_files'], 0)
+
+    def test_get_proposal_runs_first_page(self):
+        proposal_number = 0
+        resp = self.mdc_client.get_proposal_runs(proposal_number, page=2, page_size=1)
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        self.assert_eq_val(resp['app_info'], {})
+        self.assert_eq_val(resp['success'], True)
+        self.assert_eq_val(resp['info'], 'Got proposal successfully')
+
+        self.assert_eq_val(len(resp['data']['runs']), 1)
+
+        first_run = resp['data']['runs'][0]
+        self.assert_eq_val(first_run['id'], -1)
+        self.assert_eq_val(first_run['run_number'], 1)
+        self.assert_eq_val(first_run['flg_status'], 2)
+        self.assert_eq_val(first_run['flg_run_quality'], 1)
+        self.assert_eq_val(first_run['num_files'], 0)
+
+        first_repo = first_run['repositories']['XFEL_TESTS_REPO']
+        self.assert_eq_val(first_repo['name'],
+                           'XFEL Tests Repository')
+        self.assert_eq_val(first_repo['mount_point'], '/webstorage/XFEL')
+        self.assert_eq_val(first_repo['data_groups'], 1)
+
+    def test_get_proposal_runs_second_page(self):
+        proposal_number = 0
+        resp = self.mdc_client.get_proposal_runs(proposal_number, page=1, page_size=1)
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        self.assert_eq_val(resp['app_info'], {})
+        self.assert_eq_val(resp['success'], True)
+        self.assert_eq_val(resp['info'], 'Got proposal successfully')
+
+        self.assert_eq_val(len(resp['data']['runs']), 1)
+
+        second_run = resp['data']['runs'][0]
+        self.assert_eq_val(second_run['id'], -2)
+        self.assert_eq_val(second_run['run_number'], 2)
+        self.assert_eq_val(second_run['flg_status'], 1)
+        self.assert_eq_val(second_run['flg_run_quality'], -1)
+        self.assert_eq_val(second_run['num_files'], 0)
+
     def test_get_proposal_runs_with_errors(self):
         proposal_number = -99
         resp = self.mdc_client.get_proposal_runs(proposal_number)
@@ -277,6 +332,26 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
 
+    def test_get_proposal_samples_with_page_error_and_empty_data(self):
+        proposal_number = 0
+        resp = self.mdc_client.get_proposal_samples(proposal_number, page=100, page_size=100)
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        #
+        # RESPONSE example
+        #
+        # resp = {'info': 'proposal not found!',
+        #         'success': False,
+        #         'data': 'Proposal number -99 not found',
+        #         'app_info': {}}
+
+        self.assert_eq_val(resp['info'], 'Error getting sample')
+        self.assert_eq_val(resp['success'], False)
+        self.assert_eq_val(resp['app_info'], {})
+        self.assert_eq_val(resp['data'], {})
+
     def test_get_proposal_details_success(self):
         resp = self.mdc_client.get_proposal_info(900061, ['SPB', 'SA1'])
 
@@ -295,7 +370,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         self.assertEqual(prop_info['number'], 900061)
         self.assertEqual(prop_info['title'],
                          'DO NOT DELETE - CONTROLS TEST PROPOSAL 900061')
-        self.assertEqual(prop_info['abstract'], '')
+        self.assertEqual(prop_info['abstract'], None)
         self.assertEqual(prop_info['proposal_folder'], 'p900061')
         self.assertEqual(prop_info['def_proposal_path'],
                          '/gpfs/exfel/exp/SPB/200030/p900061/raw')
@@ -349,7 +424,8 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         # Expected return:
         #
         self.assert_eq_val(resp['info'], 'Error getting proposal')
-        self.assert_eq_val(resp['app_info'], "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
+        self.assert_eq_val(resp['app_info'],
+                           "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
         self.assert_eq_val(resp['success'], True)
         self.assert_eq_val(resp['data'], {})
 
