@@ -38,8 +38,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
             'flg_status': 'R',
             'pdu_karabo_das': ['t1', 't2'],
             'size': '',
-            'calcat_url': '',
-            'globus_url': '',
+            'report_url': '',
             'input_path': '',
             'output_path': '',
             'calcat_feedback': '',
@@ -63,8 +62,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
             # UPDATED FIELDS!
             'flg_status': 'R',
             'size': '',
-            'calcat_url': '',
-            'globus_url': '',
+            'report_url': '',
             'input_path': '',
             'output_path': '',
             'calcat_feedback': '',
@@ -88,8 +86,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
             # UPDATED FIELDS!
             'flg_status': 'F',
             'size': '1,5Gb',
-            'calcat_url': 'https://www.new_example.com:123#calcat_UPDATED',
-            'globus_url': 'https://www.new_example.com:123#globus_UPDATED',
+            'report_url': 'https://www.new_example.com:123#report_UPDATED',
             'input_path': '/this/is/input/path/UPDATED',
             'output_path': '/this/is/output/path/UPDATED',
             'calcat_feedback': 'This dark run performed with success UPD!',
@@ -111,8 +108,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
             flg_status=self.dark_1['flg_status'],
             pdu_karabo_das=self.dark_1['pdu_karabo_das'],
             size=self.dark_1['size'],
-            calcat_url=self.dark_1['calcat_url'],
-            globus_url=self.dark_1['globus_url'],
+            report_url=self.dark_1['report_url'],
             input_path=self.dark_1['input_path'],
             output_path=self.dark_1['output_path'],
             calcat_feedback=self.dark_1['calcat_feedback'],
@@ -153,8 +149,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
         #
         dark_run_01.flg_status = self.dark_01_upd['flg_status']
         dark_run_01.size = self.dark_01_upd['size']
-        dark_run_01.calcat_url = self.dark_01_upd['calcat_url']
-        dark_run_01.globus_url = self.dark_01_upd['globus_url']
+        dark_run_01.report_url = self.dark_01_upd['report_url']
         dark_run_01.input_path = self.dark_01_upd['input_path']
         dark_run_01.output_path = self.dark_01_upd['output_path']
         dark_run_01.calcat_feedback = self.dark_01_upd['calcat_feedback']
@@ -167,8 +162,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
         #
         dark_run_01.flg_status = self.dark_01_orig['flg_status']
         dark_run_01.size = self.dark_01_orig['size']
-        dark_run_01.calcat_url = self.dark_01_orig['calcat_url']
-        dark_run_01.globus_url = self.dark_01_orig['globus_url']
+        dark_run_01.report_url = self.dark_01_orig['report_url']
         dark_run_01.input_path = self.dark_01_orig['input_path']
         dark_run_01.output_path = self.dark_01_orig['output_path']
         dark_run_01.calcat_feedback = self.dark_01_orig['calcat_feedback']
@@ -179,11 +173,11 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
         #
         # Put entry information (update some fields should throw an error)
         #
-        dark_run_01.globus_url = '#' * 251  # String with length of 251
+        dark_run_01.report_url = '#' * 251  # String with length of 251
         dark_run_01.description = self.dark_01_upd['description']
         result7 = dark_run_01.update()
         expect_app_info = {
-            'globus_url': ['URL length allows only 250 characters']}
+            'report_url': ['URL length allows only 250 characters']}
         self.assert_update_error(MODULE_NAME, result7, expect_app_info)
 
     #
@@ -203,8 +197,7 @@ class DarkRunTest(ModuleBase, unittest.TestCase):
         self.assert_eq_hfield(receive, expect, 'flg_status', STRING)
         # self.assert_eq_hfield(receive, expect, 'pdu_karabo_das', STRING)
         self.assert_eq_hfield(receive, expect, 'size', STRING)
-        self.assert_eq_hfield(receive, expect, 'calcat_url', STRING)
-        self.assert_eq_hfield(receive, expect, 'globus_url', STRING)
+        self.assert_eq_hfield(receive, expect, 'report_url', STRING)
         self.assert_eq_hfield(receive, expect, 'input_path', STRING)
         self.assert_eq_hfield(receive, expect, 'output_path', STRING)
         self.assert_eq_hfield(receive, expect, 'calcat_feedback', STRING)
